@@ -22,15 +22,17 @@ def get_coord_system(base):
     Return:
         sympy.diffgeom.get_coord_system
     """
-    if isinstance(base, string_types) or (isinstance(base, np.ndarray)
-                                          and base.dtype.kind in {'U', 'S'}):
+    if isinstance(base, string_types) or (
+        isinstance(base, np.ndarray) and base.dtype.kind in {"U", "S"}
+    ):
         base = getattr(tfields.bases, str(base))
     if not isinstance(base, sympy.diffgeom.CoordSystem):
         bse_tpe = type(base)
         expctd_tpe = type(sympy.diffgeom.CoordSystem)
-        raise TypeError("Wrong type of coord_system base {bse_tpe}. "
-                        "Expected {expctd_tpe}"
-                        .format(**locals()))
+        raise TypeError(
+            "Wrong type of coord_system base {bse_tpe}. "
+            "Expected {expctd_tpe}".format(**locals())
+        )
     return base
 
 
@@ -42,7 +44,7 @@ def get_coord_system_name(base):
         str: name of base
     """
     if isinstance(base, sympy.diffgeom.CoordSystem):
-        base = getattr(base, 'name')
+        base = getattr(base, "name")
     # if not (isinstance(base, string_types) or base is None):
     #     baseType = type(base)
     #     raise ValueError("Coordinate system must be string_type."
@@ -76,14 +78,15 @@ def lambdified_trafo(base_old, base_new):
 
     """
     coords = tuple(base_old.coord_function(i) for i in range(base_old.dim))
-    f = sympy.lambdify(coords,
-                       base_old.coord_tuple_transform_to(base_new,
-                                                         list(coords)),
-                       modules='numpy')
+    f = sympy.lambdify(
+        coords,
+        base_old.coord_tuple_transform_to(base_new, list(coords)),
+        modules="numpy",
+    )
     return f
 
 
-def transform(array, base_old, base_new):
+def transform(array, base_old, base_new, **kwargs):
     """
     Transform the input array in place
     Args:
@@ -92,6 +95,7 @@ def transform(array, base_old, base_new):
         base_new (str or sympy.CoordSystem):
     Examples:
         Cylindrical coordinates
+        >>> import numpy as np
         >>> import tfields
         >>> cart = np.array([[0, 0, 0],
         ...                  [1, 0, 0],
@@ -119,31 +123,35 @@ def transform(array, base_old, base_new):
     """
     base_old = get_coord_system(base_old)
     base_new = get_coord_system(base_new)
-    if base_new not in base_old.transforms:
-        for baseTmp in base_new.transforms:
-            if baseTmp in base_old.transforms:
-                transform(array, base_old, baseTmp)
-                transform(array, baseTmp, base_new)
-                return
-        raise ValueError("Trafo not found.")
 
     # very fast trafos in numpy only
     short_trafo = None
     try:
-        short_trafo = getattr(base_old, 'to_{base_new.name}'.format(**locals()))
+        short_trafo = getattr(base_old, f"to_{base_new.name}".format(**locals()))
     except AttributeError:
         pass
     if short_trafo:
-        short_trafo(array)
+        short_trafo(array, **kwargs)
         return
 
+    if base_new not in base_old.transforms:
+        for baseTmp in base_new.transforms:
+            if baseTmp in base_old.transforms:
+                transform(array, base_old, baseTmp, **kwargs)
+                transform(array, baseTmp, base_new, **kwargs)
+                return
+        raise ValueError(f"Transformation {base_old} -> {base_new} not found.")
+
     # trafo via lambdified sympy expressions
     trafo = tfields.bases.lambdified_trafo(base_old, base_new)
     with warnings.catch_warnings():
-        warnings.filterwarnings('ignore', message="invalid value encountered in double_scalars")
+        warnings.filterwarnings(
+            "ignore", message="invalid value encountered in double_scalars"
+        )
         array[:] = np.concatenate([trafo(*coords).T for coords in array])
 
 
-if __name__ == '__main__':  # pragma: no cover
+if __name__ == "__main__":  # pragma: no cover
     import doctest
+
     doctest.testmod()
