@@ -294,14 +294,6 @@ class Mesh3D(tfields.TensorMaps):
                         f.write("usemtl mtl_{0}\n".format(last_scalar))
                 f.write("f {f[0]} {f[1]} {f[2]}\n".format(f=face))
 
-    @classmethod
-    def _load_stl(cls, path):
-        """
-        Factory method
-        Given a path to a stl file, construct the object
-        """
-        return tfields.Triangles3D.load(path).mesh()
-
     @classmethod
     def _load_obj(cls, path, *group_names):
         """
@@ -378,6 +370,20 @@ class Mesh3D(tfields.TensorMaps):
             mesh = mesh.cleaned()
         return mesh
 
+    def _save_stl(self, path, **kwargs):
+        """
+        Saves the mesh in stl format
+        """
+        self.triangles()._save_stl(path, **kwargs)
+
+    @classmethod
+    def _load_stl(cls, path):
+        """
+        Factory method
+        Given a path to a stl file, construct the object
+        """
+        return tfields.Triangles3D.load(path).mesh()
+
     @classmethod
     def plane(cls, *base_vectors, **kwargs):
         """
@@ -425,6 +431,8 @@ class Mesh3D(tfields.TensorMaps):
             Building symmetric geometries were never as easy:
 
             Approximated sphere with radius 1, translated in y by 2 units
+            >>> import numpy as np
+            >>> import tfields
             >>> sphere = tfields.Mesh3D.grid((1, 1, 1),
             ...                              (-np.pi, np.pi, 12),
             ...                              (-np.pi / 2, np.pi / 2, 12),
