@@ -69,8 +69,8 @@ class Triangles3D(tfields.TensorFields):
         In addition to the usual, also slice fields
 
         Examples:
-            >>> import tfields
             >>> import numpy as np
+            >>> import tfields
             >>> vectors = tfields.Tensors(np.array([range(30)] * 3).T)
             >>> triangles = tfields.Triangles3D(vectors, range(10))
             >>> assert np.array_equal(triangles[3:6],
@@ -119,6 +119,16 @@ class Triangles3D(tfields.TensorFields):
             )
         return item
 
+    def _save_stl(self, path, **kwargs):
+        """
+        Save the object to a stl file
+        """
+        import stl
+
+        shape = stl.Mesh(np.zeros(self.ntriangles(), dtype=stl.Mesh.dtype))
+        shape.vectors = self.bulk.reshape((self.ntriangles(), 3, 3))
+        shape.save(path, **kwargs)
+
     @classmethod
     def _load_stl(cls, path):
         """
@@ -149,6 +159,8 @@ class Triangles3D(tfields.TensorFields):
 
         Examples:
             >>> from sympy.abc import x
+            >>> import numpy as np
+            >>> import tfields
             >>> t = tfields.Triangles3D([[1., 2., 3.], [-4., 5., 6.], [1, 2, -6],
             ...                          [5, -5, -5], [1,0,-1], [0,1,-1],
             ...                          [-5, -5, -5], [1,0,-1], [0,1,-1]])
@@ -172,6 +184,7 @@ class Triangles3D(tfields.TensorFields):
 
         Examples:
             >>> import sympy
+            >>> import numpy as np
             >>> import tfields
             >>> x, y, z = sympy.symbols('x y z')
             >>> t = tfields.Triangles3D([[1., 2., 3.], [-4., 5., 6.], [1, 2, -6],
@@ -218,6 +231,8 @@ class Triangles3D(tfields.TensorFields):
                 before calclulating the area
 
         Examples:
+            >>> import numpy as np
+            >>> import tfields
             >>> m = tfields.Mesh3D([[1,0,0], [0,0,1], [0,0,0]],
             ...                    faces=[[0, 1, 2]])
             >>> assert np.allclose(m.triangles().areas(), np.array([0.5]))
@@ -297,6 +312,8 @@ class Triangles3D(tfields.TensorFields):
         triangles
 
         Examples:
+            >>> import numpy as np
+            >>> import tfields
             >>> m = tfields.Mesh3D([[0,0,0], [1,0,0], [-1,0,0], [0,1,0], [0,0,1]],
             ...                    faces=[[0, 1, 3],[0, 2, 3],[1,2,4], [1, 3, 4]]);
             >>> assert np.allclose(
@@ -355,6 +372,7 @@ class Triangles3D(tfields.TensorFields):
             :func:`~tfields.Triangles3D._centroids`
 
         Examples:
+            >>> import tfields
             >>> m = tfields.Mesh3D([[0,0,0], [1,0,0], [-1,0,0], [0,1,0], [0,0,1]],
             ...                    faces=[[0, 1, 3],[0, 2, 3],[1,2,4], [1, 3, 4]]);
             >>> assert m.triangles().centroids().equal(
@@ -384,6 +402,8 @@ class Triangles3D(tfields.TensorFields):
     def norms(self):
         """
         Examples:
+            >>> import numpy as np
+            >>> import tfields
             >>> m = tfields.Mesh3D([[0,0,0], [1,0,0], [-1,0,0], [0,1,0], [0,0,1]],
             ...                    faces=[[0, 1, 3],[0, 2, 3],[1,2,4], [1, 3, 4]]);
             >>> assert np.allclose(m.triangles().norms(),
@@ -410,6 +430,8 @@ class Triangles3D(tfields.TensorFields):
 
         Examples:
             empty Meshes return right formatted array
+            >>> import numpy as np
+            >>> import tfields
             >>> m = tfields.Mesh3D([], faces=[])
             >>> m.triangles()._baricentric(np.array([0.2, 0.2, 0]))
             array([], dtype=float64)
@@ -437,6 +459,8 @@ class Triangles3D(tfields.TensorFields):
             not invertable matrices [ab, ac, ab x ac] the values will be nan and
             a warning will be triggered:
             >>> import warnings
+            >>> import numpy as np
+            >>> import tfields
             >>> m3 = tfields.Mesh3D([[0,0,0], [2,0,0], [4,0,0], [0,1,0]],
             ...                     maps=[[[0, 1, 2], [0, 1, 3]]]);
             >>> with warnings.catch_warnings(record=True) as wrn:
@@ -643,6 +667,8 @@ class Triangles3D(tfields.TensorFields):
             of a triangle
 
         Examples:
+            >>> import numpy as np
+            >>> import tfields
             >>> m = tfields.Mesh3D([[0,0,0], [1,0,0], [-1,0,0], [0,1,0], [0,0,1]],
             ...                    faces=[[0, 1, 3],[0, 2, 3],[1,2,4]]);
 
